@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-
 #include <wx/wx.h>
 #include <wx/cmdline.h>
 #include <wx/intl.h>
@@ -67,10 +66,21 @@ try
   m_locale->Init();
 
 
+  // Possible debug messages:
+  //
+  //  wxLog::AddTraceMask("image");    //  Image creation and related messages
+  //  wxLog::AddTraceMask("DC");       //  Drawing related
+  //  wxLog::AddTraceMask("encoding"); //  Encoding related
+  wxLog::AddTraceMask("entering");       //  Entering and leaving functions
+  wxLog::AddTraceMask("ChooseOne");
+  wxLog::AddTraceMask("save");           //  Saving files
+  //  wxLog::AddTraceMask("module");         //  Module and DLL related
+
+
   int encoding = static_cast<int>(wxLocale::GetSystemEncoding());
   if(encoding < 0)
     encoding = wxFONTENCODING_MAX + abs(encoding);
-  wxLogDebug("encoding = %d", encoding);
+  wxLogTrace("encoding", "encoding = %d", encoding);
 
   if(wxLocale::GetSystemEncoding() == wxFONTENCODING_SYSTEM)
   {
@@ -143,7 +153,7 @@ try
   {
     if(m_file_to_open == wxEmptyString)
     {
-      const wxExpr *p_expr = m_roomlist->GetRoom("start");
+      const wxExpr *p_expr = m_roomlist->GetExpr("start");
       InitialReplace(p_expr);
     }
     else
@@ -220,7 +230,7 @@ void Application::LoadTimeGuard(const wxString &functor) throw(Exception)
 try
 {
   wxString module_name;
-  const wxExpr *clause = m_roomlist->GetRoom(functor);
+  const wxExpr *clause = m_roomlist->GetExpr(functor);
 
   get_module(module_name, *clause); 
   Module<TimeGuard> *module = new Module<TimeGuard>(module_name);
@@ -272,7 +282,7 @@ void Application::LoadRoomGuard(const wxString &functor) throw(Exception)
 try
 {
   wxString module_name;
-  const wxExpr *clause = m_roomlist->GetRoom(functor);
+  const wxExpr *clause = m_roomlist->GetExpr(functor);
 
   if(clause->Functor() == wxString("data_control"))
   {
@@ -310,7 +320,7 @@ template <class Guard> void reset_and_delete(Guard *&pg)
 
 int Application::OnExit()
 {
-  wxLogDebug("In Application::OnExit()");
+  wxLogTrace("entering", "In Application::OnExit()");
   wxLog::FlushActive();
 
   if(m_current_module != NULL)
@@ -334,7 +344,7 @@ int Application::OnExit()
 
   delete m_locale;
 
-  wxLogDebug("wxApp::OnExit()");
+  wxLogTrace("entering", "wxApp::OnExit()");
   return wxApp::OnExit();
 }
 
@@ -470,7 +480,7 @@ WindowContents *Application::GetCurrentWC() throw(SilentException)
 void Application::InitialReplace(const wxExpr *p_expr) throw(Exception)
 try
 {
-  wxLogDebug("Application::InitialReplace");
+  wxLogTrace("entering", "Application::InitialReplace");
   int time;
 
   //////////////// Get the required attributes ////////////////
@@ -529,7 +539,7 @@ try
   
   try
   {
-    p_expr = m_roomlist->GetRoom(room_name)->Copy();
+    p_expr = m_roomlist->GetExpr(room_name)->Copy();
   }
   catch(NullException &ex)
   {
@@ -639,13 +649,14 @@ void Application::RemoveRoomGuard(RoomGuard* &rg)
 void Application::Save(const wxString &filename) throw(Exception)
 try
 {
-  wxLogDebug("Creating new wxExprDatabase");
+  wxLogTrace("entering", "Save(\"%s\")", filename.c_str());
+  wxLogTrace("save", "Creating new wxExprDatabase");
   wxExprDatabase *db = new wxExprDatabase();
 
   wxExpr *clause = new wxExpr("restore");
 
   {
-    wxLogDebug("  Appending current WindowContents");
+    wxLogTrace("save", "  Appending current WindowContents");
     wxExpr *wc = GetCurrentWC()->cHibernate();
     clause->AddAttributeValueString("current", wc->Functor());
     db->Append(wc);
@@ -661,7 +672,7 @@ try
     {
       try
       {
-	wxLogDebug("  Appending a RoomGuard");
+	wxLogTrace("save", "  Appending a RoomGuard");
 	rg = (*iter)->cHibernate();
 	rgname = new wxExpr(wxExprString, rg->Functor());
 	rglist->Append(rgname);
@@ -669,7 +680,7 @@ try
       }
       catch(...)
       {
-	wxLogDebug("    Caught exception.");
+	wxLogDebug("    Caught exception while adding RoomGuard during save.");
       }
     }
     clause->AddAttributeValue("room_guards", rglist);
@@ -685,7 +696,7 @@ try
     {
       try
       {
-	wxLogDebug("  Appending a TimeGuard");
+	wxLogTrace("save", "  Appending a TimeGuard");
 	tg = (*iter)->cHibernate();
 	tgname = new wxExpr(wxExprString, tg->Functor());
 	tglist->Append(tgname);
@@ -693,7 +704,7 @@ try
       } 
       catch(...)
       {
-	wxLogDebug("    Caught exception.");
+	wxLogDebug("    Caught exception while adding TimeGuard during save.");
       }
     }
     clause->AddAttributeValue("time_guards", tglist);
@@ -704,7 +715,7 @@ try
 
   db->Append(clause);
 
-  wxLogDebug("  Writing to file");
+  wxLogTrace("save", "  Writing to file");
   if(!db->Write(filename))
     throw NoisyException(_("Could not save the file!"));
 
@@ -718,11 +729,11 @@ catch(std::bad_alloc &ex)
 void Application::Restore(const wxString &filename) throw(Exception)
 try
 {
-  wxLogDebug("Restoring session...");
+  wxLogTrace("entering", "Restore(\"%s\"): Restoring session...", filename.c_str());
 
   m_roomlist->OpenFile(filename);
 
-  InitialReplace(m_roomlist->GetRoom("restore"));
+  InitialReplace(m_roomlist->GetExpr("restore"));
 }
 catch(std::bad_alloc &ex)
 {
@@ -784,3 +795,39 @@ void GetLocalizedAttribute(const wxExpr *expr, const wxString &name,
   
   throw SilentException(_("This wxExpr has no such attribute."));
 }
+
+wxColour GetColourAttribute(const wxExpr *expr, const wxString &name,
+			    long red, long green, long blue) throw(Exception)
+try
+{
+  wxExpr *local_copy = expr->Copy();
+  wxExpr *el = NULL;
+  local_copy->GetAttributeValue(name, &el);
+  if(el != NULL)
+  {
+    wxExpr *item = el->GetFirst();
+    if(item != NULL)
+    {
+      red = item->IntegerValue();
+      item = item->GetNext();
+    }
+    if(item != NULL)
+    {
+      green = item->IntegerValue();
+      item = item->GetNext();
+    }
+    if(item != NULL)
+    {
+      blue = item->IntegerValue();
+    }
+  }
+ 
+  delete local_copy;
+  return wxColour((red > 255) ? 255 : red,
+		  (green > 255) ? 255 : green,
+		  (blue > 255) ? 255 : blue);
+}
+catch(std::bad_alloc &ex)
+{
+  throw NoisyBadAlloc();
+}
