@@ -26,13 +26,16 @@
 #include <config.h>
 #include "../checksetup.h"
 
-#include "../windowcontents.h"
 #include "../exceptions.h"
-#include "finalpanel.h"
+#include "../htmlpanel.h"
+#include "../windowcontents.h"
 
 class Final: public WindowContents
 {
 public:
+  Final() throw(): m_panel(NULL), m_button_clicked(NULL) {}
+  ~Final() throw();
+
   virtual void Init(const wxExpr *expr,
 		    wxPanel *panel) throw(Exception);
 
@@ -40,9 +43,9 @@ public:
 
   virtual wxExpr* cHibernate() throw(Exception);
 
-  friend class FinalPanel;
 private:
-  FinalPanel *m_panel;
+  HtmlPanel *m_panel;
+  Function *m_button_clicked;
 };
 
 #endif // FINALSCREEN_H
