@@ -22,6 +22,7 @@
 #include <wx/object.h>
 #include <wx/wxexpr.h>
 #include <wx/panel.h>
+#include <wx/bitmap.h>
 
 #include <config.h>
 #include "../checksetup.h"
@@ -38,10 +39,13 @@ public:
 
   void OnButtonIntro(wxCommandEvent &event) throw();
   void OnButtonSkip(wxCommandEvent &event) throw();
+  void OnPaint(wxPaintEvent &event) throw();
 
 protected:
   DECLARE_EVENT_TABLE();
 
+  void Draw(wxDC &dc) throw();
+
 private:
   InitialScreen *m_is;
 };
