@@ -26,6 +26,7 @@
 #include <config.h>
 #include "../checksetup.h"
 
+#include "../theme.h"
 #include "../windowcontents.h"
 #include "initialpanel.h"
 
@@ -42,6 +43,7 @@ public:
   friend class InitialPanel;
 private:
   InitialPanel *m_panel;
+  Theme *m_theme;
 };
 
 #endif // INITIALSCREEN_H
