@@ -26,12 +26,18 @@
 #include <config.h>
 #include "../checksetup.h"
 
+// In this file:
+class Intro;			// A WindowContents class
+
 #include "../windowcontents.h"
-#include "intropanel.h"
+#include "../htmlpanel.h"
 
 class Intro: public WindowContents
 {
 public:
+  Intro() throw(): m_panel(NULL), m_gtd(NULL) {}
+  ~Intro() throw();
+
   virtual void Init(const wxExpr *expr,
 		    wxPanel *panel) throw(Exception);
 
@@ -39,11 +45,12 @@ public:
 
   virtual wxExpr* cHibernate() throw(Exception);
 
-  friend class IntroPanel;
 private:
-  IntroPanel *m_panel;
+  HtmlPanel *m_panel;
+  ::GoThroughDoor *m_gtd;
 };
 
+
 #endif // INTROSCREEN_H
 
 // 
