@@ -33,7 +33,7 @@ public:
   RoomList() throw(Exception);
   ~RoomList() throw();
 
-  const wxExpr* GetRoom(const wxString &room) const throw(NullException);
+  const wxExpr* GetExpr(const wxString &functor) const throw(NullException);
 
   void OpenFile(const wxString &filename) throw(Exception);
 
@@ -48,7 +48,6 @@ private:
 
 };
 
-
 #endif // ROOMLIST_H
 
 // 
